@@ -1,4 +1,22 @@
-#' Compute Skew-t Densities from Forecasted Quantiles (Nonlinear Optimization)
+#' @title Compute Skew-t Densities from Quantiles  (Non-Linear Optimization)
+#'
+#' @description Computes the skew-t density from a matrix of quantiles using non-linear optimization method.
+#'
+#' @param quantiles A matrix of quantiles. Each row represents a time observation, and each column corresponds to a quantile level.
+#' @param levels A numeric vector of the quantile levels corresponding to the columns of the quantile matrix (default: c(0.05, 0.25, 0.50, 0.75, 0.95)).
+#' @param est_points Integer. The number of evaluation points for the estimated density (default: 512).
+#' @param random_samples Integer. The number of random samples to draw from the fitted skew-t distribution (default: 5000).
+#' @param support Numeric vector of length 2. Defines the lower and upper limits of the density evaluation range. Used with \code{est_points} to create the evaluation grid. Default: \code{c(-10, 10)}.
+#' @param seed Optional integer to set the random seed for reproducibility.
+#' 
+#' @return 
+#' An object of class \code{"fars_density"}, which is a list containing:
+#' \describe{
+#'   \item{density}{A matrix of estimated densities for each time period (rows) across estimation points (columns).}
+#'   \item{distribution}{A matrix of random draws from the fitted skew-t distribution for each time period.}
+#'   \item{optimization}{The optimization method used (either 'nloptr' or 'optim').}
+#'   \item{eval_points}{The sequence of evaluation points used to compute the density. Useful for plotting.}
+#'}
 #'
 #' @import sn
 #' @import nloptr
@@ -25,7 +43,7 @@ nl_density <- function(quantiles,
   message("Estimating skew-t densities from forecasted quantiles...")
   
   # Support
-  x_vals <- seq(support[1], support[2], length.out = est_points)
+  eval_points <- seq(support[1], support[2], length.out = est_points)
   
   for (tt in 1:n_obs) {
     
@@ -37,10 +55,15 @@ nl_density <- function(quantiles,
 
     # Starting parameters for optimization
     x0 <- c(l0, s0, sh0)
-    LB <- c(l0 - 10, -Inf, -Inf)
-    UB <- c(l0 + 20, Inf, Inf)
-
     
+    # LB <- c(l0 - 10, -Inf, -Inf)
+    # UB <- c(l0 + 20, Inf, Inf)
+    
+    
+    LB <- c(l0 - 3, -Inf, -Inf)
+    UB <- c(l0 + 3, Inf, Inf)
+
+
    
     # Objective function
     objective_fn <- function(x) {
@@ -74,7 +97,7 @@ nl_density <- function(quantiles,
                                   alpha = alpha_opt)
     
     # Evaluate density
-    density_matrix[tt, ] <- dst(x_vals, 
+    density_matrix[tt, ] <- dst(eval_points, 
                                 xi = xi_opt, 
                                 omega = omega_opt, 
                                 alpha = alpha_opt)
@@ -84,7 +107,7 @@ nl_density <- function(quantiles,
     optimization = "Non-linear",
     density = density_matrix, 
     distribution = distribution,
-    x_vals = x_vals)
+    eval_points = eval_points)
   
   class(output) <- "fars_density"
  
